@@ -5,8 +5,9 @@ import logging
 import math
 from datetime import datetime
 from .parameter import Parameter
-from .tools import handle_date
+from .tools import handle_date, handle_db_to_list
 from flask import abort, Response
+from bson import ObjectId
 
 logging.basicConfig(
     level=logging.WARNING,
@@ -62,11 +63,52 @@ class DBConnect():
             logging.warning(str_data)
             abort(Response(str_data, 500, {}))
 
+    def find_docu(self, id: str, raise_err=True) -> dict:
+        """
+        根据id查找记录
+        :param id:记录id
+        :param raise_err:是否抛出异常（使用abort抛出），否则返回None
+        :return: 将结果转换为字典
+        """
+        if not isinstance(id, str):
+            logging.warning("类型错误，预期 %s ,却得到 %s" % (list, type(id)))
+            abort(Response("类型错误，预期 %s ,却得到 %s" % (list, type(id)), 400, {}))
+        try:
+            objId = ObjectId(id)
+        except:
+            logging.warning('id不合法，转换失败 id= %s' % (id,))
+            abort(Response('id不合法，转换失败 id= %s' % (id,), 400, {}))
+        entity = self.mongo_collection.find_one({'_id': objId})
+        if entity is None:
+            if raise_err:
+                logging.info('找不到 id= %s 的记录' % (id,))
+                abort(Response('找不到 id= %s 的记录' % (id,), 400, {}))
+            else:
+                return None
+        entity['_id'] = str(entity['_id'])
+        return dict(entity)
+
+    def find_docu_list(self, id_list: list) -> list:
+        """
+        根据id列表查找记录列表
+        :param id_list:
+        :return:
+        """
+        if not isinstance(id_list, list):
+            logging.warning("类型错误，预期 %s ,却得到 %s" % (list, type(id_list)))
+            abort(Response("类型错误，预期 %s ,却得到 %s" % (list, type(id_list)), 400, {}))
+        id_search = []
+        for id in id_list:
+            id_search.append({'_id': ObjectId(id)})
+        find_dict = {'$or': id_search}
+        data = self.mongo_collection.find(find_dict)
+        return handle_db_to_list(data)
+
     def find_paging(self, parameter: Parameter) -> dict:
         parameter.verification(
             checking=parameter.param_url,
             verify={
-                'page_size': str,  'current': str,  'columns': str,  'sort_order': str,
+                'page_size': str, 'current': str, 'columns': str, 'sort_order': str,
                 'filtered_value': str, 'start_date': str, 'end_date': str,
             },
             optional={'start_date': '', 'end_date': ''})
@@ -124,9 +166,9 @@ class DBConnect():
             }
         if sort_list:
             find_data.sort(sort_list).limit(
-                page_size).skip(page_size*current)
+                page_size).skip(page_size * current)
         else:
-            find_data.limit(page_size).skip(page_size*current)
+            find_data.limit(page_size).skip(page_size * current)
         # 处理返回数据
         query_result = []
         for data in find_data:
@@ -136,5 +178,5 @@ class DBConnect():
             'records_total': self.mongo_collection.estimated_document_count(),
             'records_filtered': records_filtered,
             'query_result': query_result,
-            'total_pages': math.ceil(records_filtered/page_size),
+            'total_pages': math.ceil(records_filtered / page_size),
         }
