@@ -33,8 +33,7 @@ class Parameter():
             'param_form': self.param_form
         }
 
-    @classmethod
-    def verification(checking: dict, verify: dict, optional: dict = {}, null_value: bool = False) -> dict:
+    def verification(self, checking: dict, verify: dict, optional: dict = {}, null_value: bool = False) -> dict:
         for opt_k, opt_v in optional.items():
             # 没有选填参数时，填充预设的默认值
             if not checking.__contains__(opt_k):
